#!/usr/bin/env python
#
# Copyright (c) 2014, 2015, 2016 Samsung Electronics.Co.Ltd.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; version 2 of the License
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
"""This script is used to update git-ref-mapping"""

import os
import sys

from common.buildtrigger import trigger_info
from common.git import Git
from common.mapping import git_ref_map
import xml.etree.cElementTree as ElementTree
from lxml import etree

XML_DECLARATION = """<?xml version="1.0" encoding="UTF-8" ?>"""

def main():
    """The main body"""

    # parameters
    if os.getenv('profile') is not None and os.getenv('release_id') is not None:
        base_project = os.getenv('profile')
        release_id = os.getenv('release_id')
        release_version = release_id.split('_')[-1]
        print 'Manual trigger: %s, %s' % (base_project, release_id)
    else:
        fields = trigger_info(os.getenv('TRIGGER_INFO'))
        profile = fields['profile']
        base_project = fields['base_project']
        release_id = fields['release_id']
        release_version = release_id.split('_')[-1]

    prjdir = os.path.join(os.getenv('WORKSPACE'), os.path.basename(os.getenv('REF_MAPPING_PRJ')))
    mapping_file = '{0}/git-ref-mapping.xml'.format(prjdir)

    # retrieve contents from mapping xml
    found = git_ref_map(prjdir, mapping_file, base_project=base_project)
    if not os.path.exists(mapping_file):
        print '** NO MAPPING FILE FOUND %s' % (mapping_file)
        return 1
    if len(found) == 0:
        print '** REF MAP HAVE NO ITEMS FOR %s' % (base_project)
        return

    # replace old version to new
    need_update = False
    with open(mapping_file) as mf:
        lines = mf.readlines()
    parser = etree.XMLParser(remove_comments=False)
    tree = etree.fromstring(''.join(lines))

    for dft in tree.getiterator('path'):
        for item in dft.getiterator():
            if item.get('OBS_project') == base_project:
                orgn_prj = item.get('OBS_project')
                orgn_brch = item.get('name')
                old_ref = item.get('OBS_staging_project')
                new_ref = ':'.join(old_ref.split(':')[:-1]) + ':' + release_version
                if old_ref != new_ref:
                    need_update = True
                    print '  Replace [%s][%s] %s -> %s' % (orgn_prj, orgn_brch, old_ref, new_ref)
                    item.set('OBS_staging_project', new_ref)

    new_xml_string = XML_DECLARATION + '\n' + etree.tostring(tree)

    # update git repository
    if need_update:
        with open(mapping_file, 'w') as mf:
            mf.write(new_xml_string)
        mygit = Git(prjdir)
        mygit.add_files('*', True)
        mygit.commit_staged('Updating %s => %s' % (base_project, release_id))
        mygit.push(repo = 'origin', src = 'master')
        print "\"Title\": \"%s\"" % (release_id)
    else:
        print 'No updates for git-ref-mapping.'

if __name__ == '__main__':

    sys.exit(main())

